# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
import sys
from typing import Any, Optional, TYPE_CHECKING, cast

from azure.core.pipeline import policies
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.settings import settings
from azure.mgmt.core import ARMPipelineClient
from azure.mgmt.core.policies import ARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from ._configuration import NetAppManagementClientConfiguration
from ._utils.serialization import Deserializer, Serializer
from .operations import (
    AccountsOperations,
    ActiveDirectoryConfigsOperations,
    BackupPoliciesOperations,
    BackupVaultsOperations,
    BackupsOperations,
    BackupsUnderAccountOperations,
    BackupsUnderBackupVaultOperations,
    BackupsUnderVolumeOperations,
    BucketsOperations,
    CachesOperations,
    ElasticAccountsOperations,
    ElasticBackupPoliciesOperations,
    ElasticBackupVaultsOperations,
    ElasticBackupsOperations,
    ElasticCapacityPoolsOperations,
    ElasticSnapshotPoliciesOperations,
    ElasticSnapshotsOperations,
    ElasticVolumesOperations,
    NetAppResourceOperations,
    NetAppResourceQuotaLimitsAccountOperations,
    NetAppResourceQuotaLimitsOperations,
    NetAppResourceRegionInfosOperations,
    NetAppResourceUsagesOperations,
    Operations,
    PoolsOperations,
    RansomwareReportsOperations,
    SnapshotPoliciesOperations,
    SnapshotsOperations,
    SubvolumesOperations,
    VolumeGroupsOperations,
    VolumeQuotaRulesOperations,
    VolumesOperations,
)

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self  # type: ignore

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials import TokenCredential


class NetAppManagementClient:  # pylint: disable=too-many-instance-attributes
    """Microsoft NetApp Files Azure Resource Provider specification.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.netapp.operations.Operations
    :ivar net_app_resource_quota_limits_account: NetAppResourceQuotaLimitsAccountOperations
     operations
    :vartype net_app_resource_quota_limits_account:
     azure.mgmt.netapp.operations.NetAppResourceQuotaLimitsAccountOperations
    :ivar volume_groups: VolumeGroupsOperations operations
    :vartype volume_groups: azure.mgmt.netapp.operations.VolumeGroupsOperations
    :ivar backups: BackupsOperations operations
    :vartype backups: azure.mgmt.netapp.operations.BackupsOperations
    :ivar volumes: VolumesOperations operations
    :vartype volumes: azure.mgmt.netapp.operations.VolumesOperations
    :ivar snapshots: SnapshotsOperations operations
    :vartype snapshots: azure.mgmt.netapp.operations.SnapshotsOperations
    :ivar snapshot_policies: SnapshotPoliciesOperations operations
    :vartype snapshot_policies: azure.mgmt.netapp.operations.SnapshotPoliciesOperations
    :ivar backup_policies: BackupPoliciesOperations operations
    :vartype backup_policies: azure.mgmt.netapp.operations.BackupPoliciesOperations
    :ivar volume_quota_rules: VolumeQuotaRulesOperations operations
    :vartype volume_quota_rules: azure.mgmt.netapp.operations.VolumeQuotaRulesOperations
    :ivar ransomware_reports: RansomwareReportsOperations operations
    :vartype ransomware_reports: azure.mgmt.netapp.operations.RansomwareReportsOperations
    :ivar backup_vaults: BackupVaultsOperations operations
    :vartype backup_vaults: azure.mgmt.netapp.operations.BackupVaultsOperations
    :ivar buckets: BucketsOperations operations
    :vartype buckets: azure.mgmt.netapp.operations.BucketsOperations
    :ivar caches: CachesOperations operations
    :vartype caches: azure.mgmt.netapp.operations.CachesOperations
    :ivar elastic_accounts: ElasticAccountsOperations operations
    :vartype elastic_accounts: azure.mgmt.netapp.operations.ElasticAccountsOperations
    :ivar elastic_capacity_pools: ElasticCapacityPoolsOperations operations
    :vartype elastic_capacity_pools: azure.mgmt.netapp.operations.ElasticCapacityPoolsOperations
    :ivar elastic_volumes: ElasticVolumesOperations operations
    :vartype elastic_volumes: azure.mgmt.netapp.operations.ElasticVolumesOperations
    :ivar elastic_snapshots: ElasticSnapshotsOperations operations
    :vartype elastic_snapshots: azure.mgmt.netapp.operations.ElasticSnapshotsOperations
    :ivar elastic_snapshot_policies: ElasticSnapshotPoliciesOperations operations
    :vartype elastic_snapshot_policies:
     azure.mgmt.netapp.operations.ElasticSnapshotPoliciesOperations
    :ivar elastic_backup_vaults: ElasticBackupVaultsOperations operations
    :vartype elastic_backup_vaults: azure.mgmt.netapp.operations.ElasticBackupVaultsOperations
    :ivar elastic_backup_policies: ElasticBackupPoliciesOperations operations
    :vartype elastic_backup_policies: azure.mgmt.netapp.operations.ElasticBackupPoliciesOperations
    :ivar elastic_backups: ElasticBackupsOperations operations
    :vartype elastic_backups: azure.mgmt.netapp.operations.ElasticBackupsOperations
    :ivar active_directory_configs: ActiveDirectoryConfigsOperations operations
    :vartype active_directory_configs:
     azure.mgmt.netapp.operations.ActiveDirectoryConfigsOperations
    :ivar net_app_resource_quota_limits: NetAppResourceQuotaLimitsOperations operations
    :vartype net_app_resource_quota_limits:
     azure.mgmt.netapp.operations.NetAppResourceQuotaLimitsOperations
    :ivar net_app_resource_region_infos: NetAppResourceRegionInfosOperations operations
    :vartype net_app_resource_region_infos:
     azure.mgmt.netapp.operations.NetAppResourceRegionInfosOperations
    :ivar accounts: AccountsOperations operations
    :vartype accounts: azure.mgmt.netapp.operations.AccountsOperations
    :ivar backups_under_account: BackupsUnderAccountOperations operations
    :vartype backups_under_account: azure.mgmt.netapp.operations.BackupsUnderAccountOperations
    :ivar pools: PoolsOperations operations
    :vartype pools: azure.mgmt.netapp.operations.PoolsOperations
    :ivar backups_under_backup_vault: BackupsUnderBackupVaultOperations operations
    :vartype backups_under_backup_vault:
     azure.mgmt.netapp.operations.BackupsUnderBackupVaultOperations
    :ivar backups_under_volume: BackupsUnderVolumeOperations operations
    :vartype backups_under_volume: azure.mgmt.netapp.operations.BackupsUnderVolumeOperations
    :ivar subvolumes: SubvolumesOperations operations
    :vartype subvolumes: azure.mgmt.netapp.operations.SubvolumesOperations
    :ivar net_app_resource: NetAppResourceOperations operations
    :vartype net_app_resource: azure.mgmt.netapp.operations.NetAppResourceOperations
    :ivar net_app_resource_usages: NetAppResourceUsagesOperations operations
    :vartype net_app_resource_usages: azure.mgmt.netapp.operations.NetAppResourceUsagesOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword api_version: The API version to use for this operation. Known values are
     "2026-04-15-preview" and None. Default value is None. If not set, the operation's default API
     version will be used. Note that overriding this default value may result in unsupported
     behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = NetAppManagementClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                ARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=cast(str, _endpoint), policies=_policies, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.net_app_resource_quota_limits_account = NetAppResourceQuotaLimitsAccountOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.volume_groups = VolumeGroupsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backups = BackupsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.volumes = VolumesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.snapshots = SnapshotsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.snapshot_policies = SnapshotPoliciesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_policies = BackupPoliciesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.volume_quota_rules = VolumeQuotaRulesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.ransomware_reports = RansomwareReportsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_vaults = BackupVaultsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.buckets = BucketsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.caches = CachesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.elastic_accounts = ElasticAccountsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_capacity_pools = ElasticCapacityPoolsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_volumes = ElasticVolumesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.elastic_snapshots = ElasticSnapshotsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_snapshot_policies = ElasticSnapshotPoliciesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_backup_vaults = ElasticBackupVaultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_backup_policies = ElasticBackupPoliciesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.elastic_backups = ElasticBackupsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.active_directory_configs = ActiveDirectoryConfigsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.net_app_resource_quota_limits = NetAppResourceQuotaLimitsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.net_app_resource_region_infos = NetAppResourceRegionInfosOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.accounts = AccountsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backups_under_account = BackupsUnderAccountOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.pools = PoolsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backups_under_backup_vault = BackupsUnderBackupVaultOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backups_under_volume = BackupsUnderVolumeOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.subvolumes = SubvolumesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.net_app_resource = NetAppResourceOperations(self._client, self._config, self._serialize, self._deserialize)
        self.net_app_resource_usages = NetAppResourceUsagesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def send_request(self, request: HttpRequest, *, stream: bool = False, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Self:
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)
