# resource constants
# some minor setup required to run in record mode
#  - actual subsid to be used
#  - rg must exist
#  - vnet must exist
LOCATION = "westus2"
REMOTE_LOCATION = "eastus2"
TEST_RG = "sdk-python-tests-rg-tmp"
TEST_REPL_REMOTE_RG = "sdk-python-tests-rg-R-tmp"
TEST_ACC_1 = "sdk-py-tests-acc-1"
TEST_ACC_2 = "sdk-py-tests-acc-2"
TEST_POOL_1 = "sdk-py-tests-pool-1"
TEST_POOL_2 = "sdk-py-tests-pool-2"
TEST_VOL_1 = "sdk-py-tests-vol-3"
TEST_VOL_2 = "sdk-py-tests-vol-4"
TEST_BACKUP_1 = "sdk-py-tests-backups-1"
TEST_BACKUP_2 = "sdk-py-tests-backups-2"
TEST_SUBVOLUME_1 = "sdk-py-tests-subvolume-1"
TEST_SUBVOLUME_2 = "sdk-py-tests-subvolume-2"
TEST_SNAPSHOT_1 = "sdk-py-tests-snapshot-1"
TEST_SNAPSHOT_2 = "sdk-py-tests-snapshot-2"
SERVICE_LEVEL = "Premium"
REMOTE_VNET = "sdk-python-tests-VNET-R"
PERMA_ACCOUNT = "sdk-python-perma-account"
PERMA_REMOTE_ACCOUNT = "sdk-python-perma-remote-account"
PERMA_POOL = "sdk-python-perma-pool"
PERMA_REMOTE_POOL = "sdk-python-perma-remote-pool"
PERMA_VOLUME = "sdk-python-perma-volume"
PERMA_REMOTE_VOLUME = "sdk-python-perma-remote-volume"
PERMA_VNET = "sdk-python-tests-perma-VNET"
PERMA_REMOTE_VNET = "sdk-python-tests-remote-perma-VNET"
PERMA_SUBNET = "sdk-python-tests-subnet"
PERMA_REMOTE_SUBNET = "sdk-python-tests-remote-subnet"
LIVE = False
SUBSID = "69a75bda-882e-44d5-8431-63421204132a"
