# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import NetAppResourceQuotaLimitsAccountOperations  # type: ignore
from ._operations import VolumeGroupsOperations  # type: ignore
from ._operations import BackupsOperations  # type: ignore
from ._operations import VolumesOperations  # type: ignore
from ._operations import SnapshotsOperations  # type: ignore
from ._operations import SnapshotPoliciesOperations  # type: ignore
from ._operations import BackupPoliciesOperations  # type: ignore
from ._operations import VolumeQuotaRulesOperations  # type: ignore
from ._operations import RansomwareReportsOperations  # type: ignore
from ._operations import BackupVaultsOperations  # type: ignore
from ._operations import BucketsOperations  # type: ignore
from ._operations import CachesOperations  # type: ignore
from ._operations import ElasticAccountsOperations  # type: ignore
from ._operations import ElasticCapacityPoolsOperations  # type: ignore
from ._operations import ElasticVolumesOperations  # type: ignore
from ._operations import ElasticSnapshotsOperations  # type: ignore
from ._operations import ElasticSnapshotPoliciesOperations  # type: ignore
from ._operations import ElasticBackupVaultsOperations  # type: ignore
from ._operations import ElasticBackupPoliciesOperations  # type: ignore
from ._operations import ElasticBackupsOperations  # type: ignore
from ._operations import ActiveDirectoryConfigsOperations  # type: ignore
from ._operations import NetAppResourceQuotaLimitsOperations  # type: ignore
from ._operations import NetAppResourceRegionInfosOperations  # type: ignore
from ._operations import AccountsOperations  # type: ignore
from ._operations import BackupsUnderAccountOperations  # type: ignore
from ._operations import PoolsOperations  # type: ignore
from ._operations import BackupsUnderBackupVaultOperations  # type: ignore
from ._operations import BackupsUnderVolumeOperations  # type: ignore
from ._operations import SubvolumesOperations  # type: ignore
from ._operations import NetAppResourceOperations  # type: ignore
from ._operations import NetAppResourceUsagesOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "NetAppResourceQuotaLimitsAccountOperations",
    "VolumeGroupsOperations",
    "BackupsOperations",
    "VolumesOperations",
    "SnapshotsOperations",
    "SnapshotPoliciesOperations",
    "BackupPoliciesOperations",
    "VolumeQuotaRulesOperations",
    "RansomwareReportsOperations",
    "BackupVaultsOperations",
    "BucketsOperations",
    "CachesOperations",
    "ElasticAccountsOperations",
    "ElasticCapacityPoolsOperations",
    "ElasticVolumesOperations",
    "ElasticSnapshotsOperations",
    "ElasticSnapshotPoliciesOperations",
    "ElasticBackupVaultsOperations",
    "ElasticBackupPoliciesOperations",
    "ElasticBackupsOperations",
    "ActiveDirectoryConfigsOperations",
    "NetAppResourceQuotaLimitsOperations",
    "NetAppResourceRegionInfosOperations",
    "AccountsOperations",
    "BackupsUnderAccountOperations",
    "PoolsOperations",
    "BackupsUnderBackupVaultOperations",
    "BackupsUnderVolumeOperations",
    "SubvolumesOperations",
    "NetAppResourceOperations",
    "NetAppResourceUsagesOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
